LatexConstants class

LaTeX Base Module Constants

Contains only parser-related configuration parameters. Rendering-related typesetting constants have been migrated to the MathConstants object in the latex-renderer module.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited