ILogger class abstract
Constructors
- ILogger()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
d(
String tag, String message) → void -
e(
String tag, String message, [Object? error, StackTrace? stackTrace]) → void -
i(
String tag, String message) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
v(
String tag, String message) → void -
w(
String tag, String message) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited