CommandParser class

Constructors

CommandParser(LatexParserContext context, ChemicalParser chemicalParser)

Properties

chemicalParser → ChemicalParser
final
context → LatexParserContext
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenStream → LatexTokenStream
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseCommand(String cmdName) → LatexNode?
Parses a command
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

tag → const String