LatexNode class abstract
- Implementers
- AccentNode
- AlignedNode
- ArrayNode
- BigOperatorNode
- BinomialNode
- BoxedNode
- CasesNode
- CLineNode
- ColorBoxNode
- ColorNode
- CommandNode
- DelimitedNode
- DisplayMathNode
- DocumentNode
- EncloseNode
- EnvironmentNode
- EqnarrayNode
- EqRefNode
- ErrorNode
- ExtensibleArrowNode
- FontSizeNode
- FractionNode
- GroupNode
- HLineNode
- HPhantomNode
- HSpaceNode
- HyperlinkNode
- InlineMathNode
- LabelNode
- LayoutNode
- ManualSizedDelimiterNode
- MathLapNode
- MathStyleNode
- MatrixNode
- ModOperatorNode
- MulticolumnNode
- MultlineNode
- NegationNode
- NewCommandNode
- NewEnvironmentNode
- NewLineNode
- OperatorNameNode
- OperatorNode
- PhantomNode
- PrescriptNode
- RefNode
- RootNode
- SectionHeadingNode
- SideSetNode
- SmashNode
- SpaceNode
- SplitNode
- StackNode
- StyleNode
- SubequationsNode
- SubscriptNode
- SubstackNode
- SuperscriptNode
- SymbolNode
- TabularNode
- TagNode
- TensorNode
- TextDirectionNode
- TextModeNode
- TextNode
- VPhantomNode
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRange → SourceRange?
-
no setter
Methods
-
accept<
T> (LatexVisitor< T> visitor) → T - Double-dispatch: Dispatches the visitor to the corresponding visit method
-
children(
) → List< LatexNode> - Returns all direct child nodes (ordered). Leaf nodes return an empty list.
-
fold<
T> (T initial, T combine(T acc, LatexNode node)) → T -
Depth-first fold: Applies
combineto itself and all descendant nodes. -
mapNodes(
LatexNode transform(LatexNode node)) → LatexNode -
Depth-first map: Applies
transformto each node, rebuilding the tree bottom-up. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuildRows(
List< List< originalRows, List<LatexNode> >LatexNode> newChildren) → List<List< LatexNode> > - Generic implementation to rebuild rows based on the original row structure. Shared by Matrix/Array/Aligned/Split/Eqnarray/Tabular/Substack.
-
toString(
) → String -
A string representation of this object.
override
-
withChildren(
List< LatexNode> newChildren) → LatexNode - Rebuilds itself with a new list of child nodes. The order and number of child nodes must match the return value of children. Leaf nodes return themselves.
-
withSourceRange(
SourceRange range) → LatexNode - Creates a copy with a new sourceRange
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited