AccentType enum

Inheritance
Available extensions

Values

hat → const AccentType
tilde → const AccentType
bar → const AccentType
dot → const AccentType
ddot → const AccentType
dddot → const AccentType
vec → const AccentType
overline → const AccentType
underline → const AccentType
overBrace → const AccentType
underBrace → const AccentType
wideHat → const AccentType
overRightArrow → const AccentType
overLeftArrow → const AccentType
cancel → const AccentType
bCancel → const AccentType
xCancel → const AccentType
grave → const AccentType
acute → const AccentType
check → const AccentType
breve → const AccentType
ring → const AccentType
overBracket → const AccentType
underBracket → const AccentType
wideCheck → const AccentType
overLeftRightArrow → const AccentType
underLeftArrow → const AccentType
underRightArrow → const AccentType
overParen → const AccentType
underParen → const AccentType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AccentType>
A constant List of the values in this enum, in order of their declaration.