ArrowDirection enum
可扩展箭头方向枚举
Values
- right → const ArrowDirection
- left → const ArrowDirection
- both → const ArrowDirection
- hookRight → const ArrowDirection
- hookLeft → const ArrowDirection
- rightDouble → const ArrowDirection
- leftDouble → const ArrowDirection
- bothDouble → const ArrowDirection
- mapsto → const ArrowDirection
- equal → const ArrowDirection
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ArrowDirection> - A constant List of the values in this enum, in order of their declaration.