Notation enum

MathML notation 围框/删除线类型

Inheritance
Available extensions

Values

longdiv → const Notation
const Notation('longdiv')
actuarial → const Notation
const Notation('actuarial')
box → const Notation
const Notation('box')
roundedBox → const Notation
const Notation('roundedbox')
circle → const Notation
const Notation('circle')
left → const Notation
const Notation('left')
const Notation('right')
top → const Notation
const Notation('top')
bottom → const Notation
const Notation('bottom')
upDiagonalStrike → const Notation
const Notation('updiagonalstrike')
downDiagonalStrike → const Notation
const Notation('downdiagonalstrike')
verticalStrike → const Notation
const Notation('verticalstrike')
horizontalStrike → const Notation
const Notation('horizontalstrike')
madruwb → const Notation
const Notation('madruwb')
upDiagonalArrow → const Notation
const Notation('updiagonalarrow')
phasorAngle → const Notation
const Notation('phasorangle')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
mathMlName String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMathMlName(String name) Notation?

Constants

values → const List<Notation>
A constant List of the values in this enum, in order of their declaration.