withChildren method

  1. @override
LatexNode withChildren(
  1. List<LatexNode> newChildren
)
override

Rebuilds itself with a new list of child nodes. The order and number of child nodes must match the return value of children. Leaf nodes return themselves.

Implementation

@override
LatexNode withChildren(List<LatexNode> newChildren) {
  final newContent = newChildren[0];
  final newIndex = index != null ? newChildren[1] : null;
  return RootNode(newContent, index: newIndex, sourceRange: sourceRange);
}