withChildren method
Rebuilds itself with a new list of child nodes. The order and number of child nodes must match the return value of children. Leaf nodes return themselves.
Implementation
@override
LatexNode withChildren(List<LatexNode> newChildren) => SectionHeadingNode(
newChildren,
level,
starred: starred,
sourceRange: sourceRange,
);