TagNode class
Formula Numbering Tag Node (\tag, \tag*)
Constructors
- TagNode(LatexNode label, {bool starred = false, SourceRange? sourceRange})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → LatexNode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRange → SourceRange?
-
final
- starred → bool
-
true = \tag* (no parentheses), false = \tag (with parentheses)
final
Methods
-
accept<
T> (LatexVisitor< T> visitor) → T -
Double-dispatch: Dispatches the visitor to the corresponding visit method
override
-
children(
) → List< LatexNode> -
Returns all direct child nodes (ordered). Leaf nodes return an empty list.
override
-
fold<
T> (T initial, T combine(T acc, LatexNode node)) → T -
Depth-first fold: Applies
combineto itself and all descendant nodes.inherited -
mapNodes(
LatexNode transform(LatexNode node)) → LatexNode -
Depth-first map: Applies
transformto each node, rebuilding the tree bottom-up.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuildRows(
List< List< originalRows, List<LatexNode> >LatexNode> newChildren) → List<List< LatexNode> > -
Generic implementation to rebuild rows based on the original row structure.
Shared by Matrix/Array/Aligned/Split/Eqnarray/Tabular/Substack.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withChildren(
List< LatexNode> newChildren) → LatexNode -
Rebuilds itself with a new list of child nodes.
The order and number of child nodes must match the return value of children.
Leaf nodes return themselves.
override
-
withSourceRange(
SourceRange range) → LatexNode -
Creates a copy with a new sourceRange
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited