TensorIndex class

Helper class for Tensor indices (Boolean indicates whether index is a superscript)

Constructors

TensorIndex({required bool isSuper, required LatexNode node})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isSuper bool
final
node LatexNode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited