LatexParser class

LaTeX Syntax Parser

Component-based architecture:

Constructors

LatexParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String input) DocumentNode
Parses a LaTeX string
parseFromTokens(List<LatexToken> tokens, int inputLength) DocumentNode
Parses directly from a token list (for use by the incremental parser to avoid re-tokenization)
parseWithDiagnostics(String input) ParseResult
Parses a LaTeX string and returns a ParseResult containing AST and structured diagnostic information
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

tag → const String