SymbolMap class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getAccessibleName(
String commandName) → String? - 根据 LaTeX 命令名获取英文可读名称(用于无障碍文本)
-
getAccessibleNameByUnicode(
String unicode) → String? - 根据 Unicode 字符获取英文可读名称(用于无障碍文本)
-
getAllSymbols(
) → Map< String, String> -
getSymbol(
String name) → String?