LatexToken class sealed

LaTeX Lexical Token

Each token carries a range recording its position in the original input string.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
range → SourceRange
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withRange(SourceRange newRange) → LatexToken
Creates a copy with a new SourceRange (eliminating when-dispatch in shiftToken)

Operators

operator ==(Object other) → bool
The equality operator.
inherited