RightBracketToken class
- Inheritance
-
- Object
- LatexToken
- RightBracketToken
Constructors
- RightBracketToken({SourceRange range = SourceRange.empty})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- range → SourceRange
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withRange(
SourceRange newRange) → LatexToken -
Creates a copy with a new SourceRange (eliminating when-dispatch in shiftToken)
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited