CursorPosition class

Cursor pixel position.

x X coordinate relative to the content area origin. y Y coordinate relative to the content area origin (top of the cursor). height Cursor height.

Constructors

CursorPosition({required double x, required double y, required double height})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
final
y → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited