LatexEditor class
LaTeX Editor Component.
3-Layer Architecture:
- Hidden TextField — Receives keyboard input and IME events.
- LatexEditorCanvas — Renders LaTeX formulas.
- Cursor/Selection Overlay — Draws the blinking cursor and selection highlights.
Note: Editor features are currently experimental, APIs may change in subsequent versions.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LatexEditor
Constructors
- LatexEditor({Key? key, required EditorState editorState, LatexConfig config = const LatexConfig(), bool? isDarkTheme, Color? cursorColor, Color? selectionColor, bool showSourceText = false})
-
const
Properties
- config → LatexConfig
-
final
- cursorColor → Color?
-
final
- editorState → EditorState
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkTheme → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionColor → Color?
-
final
- showSourceText → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< LatexEditor> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited