TemplateExpansion class

Template expansion result.

text The expanded LaTeX text. cursorDelta The cursor offset relative to the start position of the insertion point.

Constructors

TemplateExpansion({required String text, required int cursorDelta})
const

Properties

cursorDelta int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited