SlotNavigator class

Slot Navigator.

Navigates through the input slots of compound structures (fractions, sub/superscripts, roots etc.). Typical use case: After inserting a \frac{}{} template, use Enter to jump: Numerator -> Denominator -> After the fraction.

Note: Editor features are currently experimental, APIs may change in subsequent versions.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

nextSlotOffset(int cursorOffset, LatexNode document) int?
Calculates the cursor offset of the next slot.