fontFamilyFor abstract method
We return dynamic here to remain agnostic to the UI framework's
specific FontFamily equivalent (e.g., String or a concrete TextStyle type).
Implementation
dynamic fontFamilyFor(MathFontRole role);
We return dynamic here to remain agnostic to the UI framework's
specific FontFamily equivalent (e.g., String or a concrete TextStyle type).
dynamic fontFamilyFor(MathFontRole role);