TtfFontSetProvider class

TeX typesetting metrics for the built-in KaTeX TTF font set.

Implemented types

Constructors

TtfFontSetProvider(dynamic fontFamilies)

Properties

fontFamilies → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

axisHeight(double fontSizePx) double
override
fontBytes(MathFontRole role) Uint8List?
override
fontFamilyFor(MathFontRole role) → dynamic
We return dynamic here to remain agnostic to the UI framework's specific FontFamily equivalent (e.g., String or a concrete TextStyle type).
override
fractionDenominatorDisplayGap(double fontSizePx) double
override
fractionDenominatorGap(double fontSizePx) double
override
fractionDenominatorShiftDown(double fontSizePx, bool displayStyle) double
override
fractionNumeratorDisplayGap(double fontSizePx) double
override
fractionNumeratorGap(double fontSizePx) double
override
fractionNumeratorShiftUp(double fontSizePx, bool displayStyle, bool hasRule) double
override
fractionRuleThickness(double fontSizePx) double
override
italicCorrection(String glyphChar, double fontSizePx) double
override
lowerLimitGap(double fontSizePx, double limitHeightPx) double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
radicalDisplayVerticalGap(double fontSizePx) double
override
radicalRuleThickness(double fontSizePx) double
override
radicalVerticalGap(double fontSizePx) double
override
spaceAfterScript(double fontSizePx) double
override
subscriptDrop(double fontSizePx) double
override
subscriptShiftDown(double fontSizePx, {bool? hasSuperscript}) double
Likewise, emulates both subscriptShiftDown signatures.
override
subSuperscriptGapMin(double fontSizePx) double
override
superscriptDrop(double fontSizePx) double
override
superscriptShiftUp(double fontSizePx, {bool? displayStyle, bool? crampedStyle}) double
In Dart, method overloading is not permitted. Named optional parameters successfully emulate the separate signatures for superscriptShiftUp found in the Kotlin source.
override
topAccentAttachment(String glyphChar, double fontSizePx, double glyphAdvancePx) double
override
toString() String
A string representation of this object.
inherited
upperLimitGap(double fontSizePx, double limitDepthPx) double
override
xHeight(double fontSizePx) double
override

Operators

operator ==(Object other) bool
The equality operator.
inherited