EquationNumbering class

Equation numbering auto-calculator.

Traverses the AST to precompute the \label{key} -> number mapping

Constructors

EquationNumbering()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buildLabelMap(List<LatexNode> children) → Map<String, String>
Precomputes the label -> number mapping for the entire document
isNumberedEnvName(String envName) → bool