GroupLayoutPostProcessor class
Inline layout post-processor.
Performs secondary adjustments on specific nodes (like integral operators) based on context after the initial measureGroup phase
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fillDeferredIntegrals(
{required List< LatexNode> nodes, required List<NodeLayout?> layouts, required RenderContext context, LayoutCache? cache}) → List<NodeLayout> - Fills deferred integral nodes.