LatexRenderer class

LaTeX core renderer: encapsulates the shared logic of "measure + draw".

Shared between the LaTeX Widget and Exporters to ensure 100% consistent rendering.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

draw(Canvas canvas, LatexRenderResult renderResult, {Color backgroundColor = Colors.transparent}) → void
Draws the LatexRenderResult to a Canvas.
measure(List<LatexNode> children, RenderContext context, {List<HighlightRange> highlightRanges = const [], LayoutMap? layoutMap, LayoutCache? cache}) → LatexRenderResult
Measures a list of LaTeX nodes and generates a LatexRenderResult.