LayoutCache class

NodeLayout cache: Same AST subtree + Same RenderContext -> reuse layout to avoid remeasuring.

Constructors

LayoutCache({int maxSize = defaultMaxSize})

Properties

hashCode int
The hash code for this object.
no setterinherited
hits int
no setter
maxSize int
final
misses int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Current cache size.
no setter

Methods

clear() → void
Clears all caches.
getGroup(List<LatexNode> nodes, RenderContext context) NodeLayout?
Queries the node group cache.
getNode(LatexNode node, RenderContext context) NodeLayout?
Queries the single node cache.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putGroup(List<LatexNode> nodes, RenderContext context, NodeLayout layout) → void
Writes to the node group cache.
putNode(LatexNode node, RenderContext context, NodeLayout layout) → void
Writes to the single node cache.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultMaxSize → const int