LayoutMap class

Layout mapping table: records the mapping relationship from AST nodes to canvas coordinates.

Constructors

LayoutMap()

Properties

entries List<NodeLayoutEntry>
Get all entries (immutable view).
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Number of entries.
no setter

Methods

add(NodeLayoutEntry entry) → void
Add a node layout entry.
addValues({required LatexNode node, required double relX, required double relY, required double width, required double height, required double baseline}) → void
Convenience method to add a node layout entry.
clear() → void
Clear all entries.
entriesInRange(SourceRange range) List<NodeLayoutEntry>
Find all entries within the specified SourceRange.
entryAt(int sourceOffset) NodeLayoutEntry?
Find the corresponding layout entry based on the source offset.
hitTest(double px, double py) NodeLayoutEntry?
Hit-test: find the deepest (smallest area) node at canvas coordinates (px, py).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited