NodeLayoutEntry class

Node layout entry: records the relative position and dimensions of a single AST node on the canvas. Coordinates are relative to the content area origin (0,0) of the root node of the LayoutMap.

Constructors

NodeLayoutEntry({required LatexNode node, required double relX, required double relY, required double width, required double height, required double baseline})

Properties

baseline → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
node → LatexNode
final
relX → double
final
relY → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited