SubstackMeasurer class

Substack Measurer — Handles \substack{line1 \ line2}.

Implemented types

Constructors

SubstackMeasurer()

Properties

handledNodeTypes Set<Type>
The set of node types this measurer can handle.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

measure({required LatexNode node, required RenderContext context, required NodeLayout measureNode(LatexNode, RenderContext), required NodeLayout measureGroup(List<LatexNode>, RenderContext)}) NodeLayout
Measures a node and returns its layout.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited