HighlightConfig class

Sub-expression highlight configuration.

Supports specifying highlight areas by LaTeX substring pattern or AST node position index Highlights are rendered as a translucent background rectangle overlaid during the Draw phase

Constructors

HighlightConfig({List<HighlightRange> ranges = const []})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
ranges → List<HighlightRange>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited