HighlightRange class

Single highlight range.

pattern LaTeX substring pattern (exact match with the rendered text content). When null, specified via nodeIndices. nodeIndices Index range of the document root node's children (starting from 0, inclusive). When null, specified via pattern. color Highlight background color. borderColor Highlight border color (null means no border is drawn).

Constructors

HighlightRange({String? pattern, IntRange? nodeIndices, Color color = const Color(0x3300AAFF), Color? borderColor})
const

Properties

borderColor Color?
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
nodeIndices IntRange?
final
pattern String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited