IntRange class

Helper class to represent an integer range (inclusive), matching Kotlin's IntRange.

Constructors

IntRange(int start, int endInclusive)
const

Properties

endInclusive int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
final

Methods

contains(int value) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited