MathStyle enum

Math style mode (TeXbook 702)

Inheritance
Available extensions

Values

display → const MathStyle
const MathStyle(0)
text → const MathStyle
const MathStyle(0)
script → const MathStyle
const MathStyle(1)
scriptScript → const MathStyle
const MathStyle(2)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isScript → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptLevel → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scaleFactor() → double
toFractionChild() → MathStyle
Style transformation for fraction children (TeXbook 694)
toLimit() → MathStyle
Style transformation for large operator limits
toScript() → MathStyle
Style transformation when entering subscripts/superscripts
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MathStyle>
A constant List of the values in this enum, in order of their declaration.