FontResolver class

Centrally manages font selection and symbol font routing.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

compensatedFontWeight(int baseWeight, double scaleFactor) → FontWeight
delimiterContext(RenderContext context, {String delimiter = "(", double scale = 1.0}) → RenderContext
getFontForSymbol(SymbolRenderInfo info, LatexFontFamilies? fontFamilies) → String?
manualDelimiterFont(LatexFontFamilies? fontFamilies, double scaleFactor) → String?
resolve(FontCategory category, LatexFontFamilies? fontFamilies) → String?
resolveDelimiterFont(LatexFontFamilies? fontFamilies, double scale) → String?
resolveDelimiterGlyph(String delimiter, LatexFontFamilies? fontFamilies) → String
resolveSymbol(String symbolName, LatexFontFamilies? fontFamilies) → SymbolRenderInfo?
sym(String unicode) → SymbolRenderInfo