SymbolRenderInfo class

Symbol rendering information

Constructors

SymbolRenderInfo(String texGlyph, FontCategory fontCategory, [FontStyle fontStyle = FontStyle.normal])
const

Properties

fontCategory → FontCategory
final
fontStyle → FontStyle
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texGlyph → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited