InkBounds class

Text ink boundary result.

Traditional TextLayoutResult size returns the line box height (including ascent/descent/leading whitespace). For large mathematical symbol fonts, the line box might be larger than the actual ink area. This class provides precise ink metrics with whitespace removed.

Constructors

InkBounds({required double inkHeight, required double inkTopOffset, required double inkBaseline})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inkBaseline double
Distance from the baseline to the top of the ink area
final
inkHeight double
Ink area height (excluding whitespace)
final
inkTopOffset double
Ink area top offset relative to the line box top (i.e., the size of the top whitespace)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited