clearCache static method
void
clearCache()
Clears the cache (call this at the start of a new render cycle or when fonts change).
Implementation
static void clearCache() {
_axisHeightCache.clear();
}
Clears the cache (call this at the start of a new render cycle or when fonts change).
static void clearCache() {
_axisHeightCache.clear();
}