fractionRuleInset constant
double
const fractionRuleInset
Horizontal inset at both ends of the fraction rule / fontSize
Implementation
static const double fractionRuleInset = 0.075;
Horizontal inset at both ends of the fraction rule / fontSize
static const double fractionRuleInset = 0.075;