stackVerticalGap constant
double
const stackVerticalGap
Minimum vertical gap between Stack label and base box / fontSize
Implementation
static const double stackVerticalGap = 0.08;
Minimum vertical gap between Stack label and base box / fontSize
static const double stackVerticalGap = 0.08;