MathSpacing class

TeX standard math spacing system.

The basic spacing unit is mu (math unit), 1em = 18mu. Spacing is defined as a multiplier of fontSize.

Constructors

MathSpacing()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

classifyNode(LatexNode node) → AtomType
Classifies a LatexNode into an AtomType.
effectiveAtomType(List<LatexNode> nodes, int index) → AtomType
spaceBetween(AtomType left, AtomType right, bool isScript) → double
Returns the spacing scaling factor based on left/right atom types and current math style.