CustomCommand class
Custom command definition
Constructors
Properties
- acceptsDelimiterModifier → bool
-
Accept mathtools-style
*or[size]before the first argumentfinal - defaultArg → String?
-
Default value for the first argument (optional argument syntax \newcommand{\cmd}
default{body})final -
definition
→ List<
LatexNode> -
Definition content (list of AST nodes)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Command name (excluding the backslash)
final
- numArgs → int
-
Number of arguments (0-9)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited