CustomEnvironment class
Custom environment definition
Constructors
Properties
-
beginDef
→ List<
LatexNode> -
Content inserted when the environment begins (list of AST nodes)
final
- defaultArg → String?
-
Default value for the first argument (optional)
final
-
endDef
→ List<
LatexNode> -
Content inserted when the environment ends (list of AST nodes)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Environment name
final
- numArgs → int
-
Number of arguments (0-9)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited