LatexParserContext class abstract
Parser context interface, used to resolve circular dependencies and provide general parsing capabilities
customCommands is exposed as a mutable Map so MacroHandlers can register new commands, but only MacroHandlers should write to it; other handlers should only read
customEnvironments is exposed as a mutable Map so MacroHandlers can register new environments
diagnostics collects non-fatal diagnostic information during the parsing process
Constructors
Properties
-
customCommands
→ Map<
String, CustomCommand> -
no setter
-
customEnvironments
→ Map<
String, CustomEnvironment> -
no setter
-
diagnostics
→ List<
ParseDiagnostic> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenStream → LatexTokenStream
-
no setter
Methods
-
normalizeStyleDeclarations(
List< LatexNode> nodes) → List<LatexNode> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseArgument(
) → LatexNode? -
parseExpression(
) → LatexNode? -
parseFactor(
) → LatexNode? -
parseGroup(
) → GroupNode -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited