withChildren method
Rebuilds itself with a new list of child nodes. The order and number of child nodes must match the return value of children. Leaf nodes return themselves.
Implementation
@override
LatexNode withChildren(List<LatexNode> newChildren) {
final newCases = <(LatexNode, LatexNode)>[];
int idx = 0;
for (int i = 0; i < cases.length; i++) {
newCases.add((newChildren[idx++], newChildren[idx++]));
}
return CasesNode(
newCases,
style: style,
rowGaps: rowGaps,
sourceRange: sourceRange,
);
}