withChildren method
Rebuilds itself with a new list of child nodes. The order and number of child nodes must match the return value of children. Leaf nodes return themselves.
Implementation
@override
LatexNode withChildren(List<LatexNode> newChildren) {
final newContent = content != null ? newChildren.firstOrNull : null;
return ModOperatorNode(
modStyle,
content: newContent,
sourceRange: sourceRange,
);
}