SourceRange class

Annotations

Constructors

SourceRange(int start, int end)
const

Properties

end int
final
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
final

Methods

contains(int offset) bool
merge(SourceRange other) SourceRange
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

empty → const SourceRange