ReusePartition class

The three-segment partition result for AST subtree reuse

Constructors

ReusePartition({required List<LatexNode> prefix, required List<LatexNode> dirty, required List<LatexNode> suffix})
const

Properties

dirty List<LatexNode>
Nodes that overlap with the edit region (need re-parsing)
final
dirtyEndOffset int
The end offset of the dirty region in the old text
no setter
dirtyStartOffset int
The start offset of the dirty region in the old text
no setter
hashCode int
The hash code for this object.
no setterinherited
prefix List<LatexNode>
Nodes before the edit region (can be reused directly)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix List<LatexNode>
Nodes after the edit region (can be reused after offset shift)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited