DiagnosticCategory enum
Diagnostic category — used for structured error lists and category filtering.
Values
- general → const DiagnosticCategory
-
General diagnostic
- unknownCommand → const DiagnosticCategory
-
Unrecognized command
- missingBrace → const DiagnosticCategory
-
Missing closing brace }
- missingBracket → const DiagnosticCategory
-
Missing closing bracket ]
- mismatchedEnvironment → const DiagnosticCategory
-
Mismatched \begin/\end
- invalidArgument → const DiagnosticCategory
-
Invalid argument
- unexpectedToken → const DiagnosticCategory
-
Unexpected token
- macroError → const DiagnosticCategory
-
Custom macro/command related errors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DiagnosticCategory> - A constant List of the values in this enum, in order of their declaration.