LatexTokenizer constructor
Implementation
LatexTokenizer(this.input, {int startOffset = 0}) : _position = startOffset {
// Note: Dart's Lists grow efficiently automatically, but we can set an initial capacity
// using a filled list and clearing it if absolute performance is needed. Standard [] is preferred.
_tokens = <LatexToken>[];
}