CursorPosition class
Cursor pixel position.
x X coordinate relative to the content area origin. y Y coordinate relative to the content area origin (top of the cursor). height Cursor height.
Constructors
- CursorPosition({required double x, required double y, required double height})
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited