MathFontProvider class abstract
Unified entry point for KaTeX TTF font metrics.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
axisHeight(
double fontSizePx) → double -
fontBytes(
MathFontRole role) → Uint8List? -
fontFamilyFor(
MathFontRole role) → dynamic -
We return
dynamichere to remain agnostic to the UI framework's specificFontFamilyequivalent (e.g., String or a concrete TextStyle type). -
fractionDenominatorDisplayGap(
double fontSizePx) → double -
fractionDenominatorGap(
double fontSizePx) → double -
fractionDenominatorShiftDown(
double fontSizePx, bool displayStyle) → double -
fractionNumeratorDisplayGap(
double fontSizePx) → double -
fractionNumeratorGap(
double fontSizePx) → double -
fractionNumeratorShiftUp(
double fontSizePx, bool displayStyle, bool hasRule) → double -
fractionRuleThickness(
double fontSizePx) → double -
italicCorrection(
String glyphChar, double fontSizePx) → double -
lowerLimitGap(
double fontSizePx, double limitHeightPx) → double -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
radicalDisplayVerticalGap(
double fontSizePx) → double -
radicalRuleThickness(
double fontSizePx) → double -
radicalVerticalGap(
double fontSizePx) → double -
spaceAfterScript(
double fontSizePx) → double -
subscriptDrop(
double fontSizePx) → double -
subscriptShiftDown(
double fontSizePx, {bool? hasSuperscript}) → double -
Likewise, emulates both
subscriptShiftDownsignatures. -
subSuperscriptGapMin(
double fontSizePx) → double -
superscriptDrop(
double fontSizePx) → double -
superscriptShiftUp(
double fontSizePx, {bool? displayStyle, bool? crampedStyle}) → double -
In Dart, method overloading is not permitted.
Named optional parameters successfully emulate the separate signatures
for
superscriptShiftUpfound in the Kotlin source. -
topAccentAttachment(
String glyphChar, double fontSizePx, double glyphAdvancePx) → double -
toString(
) → String -
A string representation of this object.
inherited
-
upperLimitGap(
double fontSizePx, double limitDepthPx) → double -
xHeight(
double fontSizePx) → double
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited