EditorRenderInfo class
Editor render result information.
Provides the rendered dimensions and padding information for the editor module to position the cursor and handle clicks.
Constructors
- EditorRenderInfo({required double canvasWidth, required double canvasHeight, required double horizontalPadding, required double verticalPadding})
-
const
Properties
- canvasHeight → double
-
Full canvas height (including padding)
final
- canvasWidth → double
-
Full canvas width (including padding)
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- horizontalPadding → double
-
Horizontal padding
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verticalPadding → double
-
Vertical padding
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override