EquationNumberingState class
Equation automatic numbering state.
Shared during the measurement phase, providing:
- An auto-incrementing counter (increments for each environment requiring numbering)
- A mapping from label to number string (for \ref/\eqref references)
Constructors
-
EquationNumberingState(Map<
String, String> labelToNumber)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labelToNumber
→ Map<
String, String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
nextNumber(
) → String - Gets the next equation number
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveLabel(
String key) → String? - Resolves the number for a given label key. Returns null if not found
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited