HighlightCalculator class
Highlight area calculator.
Responsible for calculating the bounding rectangle of each highlight area in the layout based on highlight configurations (pattern or nodeIndices). The spacing calculation uses the same MathSpacing logic as measureGroup to ensure precise alignment.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
computeHighlightRects(
List< LatexNode> children, List<HighlightRange> ranges, RenderContext context, NodeLayout groupLayout, {LayoutCache? cache}) → List<MapEntry< HighlightRect, HighlightRange> > - Calculates the bounding rectangles of highlight areas.