render/layout/layout_map library
Classes
- LayoutMap
- Layout mapping table: records the mapping relationship from AST nodes to canvas coordinates.
- NodeLayoutEntry
- Node layout entry: records the relative position and dimensions of a single AST node on the canvas. Coordinates are relative to the content area origin (0,0) of the root node of the LayoutMap.