NodeLayoutEntry class
Node layout entry: records the relative position and dimensions of a single AST node on the canvas. Coordinates are relative to the content area origin (0,0) of the root node of the LayoutMap.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited