LatexTheme class abstract
- Available extensions
Constructors
- LatexTheme.adaptive({required LatexThemeColors light, required LatexThemeColors dark})
-
constfactory
- LatexTheme.fixed({required LatexThemeColors colors})
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
bool systemInDarkTheme) → LatexThemeColors -
Available on LatexTheme, provided by the LatexThemeResolver extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
auto(
{LatexThemeColors light = defaultLightColors, LatexThemeColors dark = defaultDarkColors}) → LatexTheme -
dark(
{Color color = Colors.white, Color backgroundColor = Colors.transparent}) → LatexTheme -
light(
{Color color = Colors.black, Color backgroundColor = Colors.transparent}) → LatexTheme -
material3(
BuildContext context) → LatexTheme -
material3Scheme(
ColorScheme colorScheme) → LatexTheme
Constants
- defaultDarkColors → const LatexThemeColors
- defaultLightColors → const LatexThemeColors