LayoutHints class
Layout hints: One-way layout communication channel passing from parent to child
Constructors
- LayoutHints({double? bigOpHeightHint, double? maxLineWidth, bool lineBreakingEnabled = false})
-
const
Properties
- bigOpHeightHint → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineBreakingEnabled → bool
-
final
- maxLineWidth → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? bigOpHeightHint, double? maxLineWidth, bool? lineBreakingEnabled}) → LayoutHints - Creates a copy of this LayoutHints but with the given fields replaced with the new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited