RenderContext class
Internal rendering context (state during render tree traversal)
- Available extensions
Constructors
- RenderContext({required double fontSize, double? baseFontSize, required Color color, Color errorColor = const Color(0xFFCC0000), MathStyle mathStyle = MathStyle.display, FontWeight? fontWeight, FontStyle? fontStyle, String? fontFamily, FontVariant fontVariant = FontVariant.normal, LatexFontFamilies? fontFamilies, bool isVariantFontFamily = false, LayoutHints layoutHints = const LayoutHints(), MathFontProvider? mathFontProvider, dynamic equationNumbering, TextDirectionType textDirection = TextDirectionType.ltr})
Properties
- baseFontSize → double
-
final
- cachedTextStyle → TextStyle
-
Cached TextStyle to avoid re-allocating new objects on every textStyle() call
latefinal
- color → Color
-
final
- equationNumbering → dynamic
-
final
- errorColor → Color
-
final
- fontFamilies → LatexFontFamilies?
-
final
- fontFamily → String?
-
final
- fontSize → double
-
final
- fontStyle → FontStyle?
-
final
- fontVariant → FontVariant
-
final
- fontWeight → FontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isVariantFontFamily → bool
-
final
- layoutHints → LayoutHints
-
final
- mathFontProvider → MathFontProvider?
-
final
- mathStyle → MathStyle
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textDirection → TextDirectionType
-
final
Methods
-
applyFontSize(
SizeType sizeType) → RenderContext -
Available on RenderContext, provided by the RenderContextTextExt extension
-
applyMathStyle(
MathStyleType mathStyleType) → RenderContext -
Available on RenderContext, provided by the RenderContextTextExt extension
Applies math mode (triggered by internal command) -
applyStyle(
StyleType styleType) → RenderContext -
Available on RenderContext, provided by the RenderContextTextExt extension
-
copyWith(
{double? fontSize, double? baseFontSize, Color? color, Color? errorColor, MathStyle? mathStyle, FontWeight? fontWeight, FontStyle? fontStyle, String? fontFamily, FontVariant? fontVariant, LatexFontFamilies? fontFamilies, bool? isVariantFontFamily, LayoutHints? layoutHints, MathFontProvider? mathFontProvider, dynamic equationNumbering, TextDirectionType? textDirection}) → RenderContext -
grow(
double factor) → RenderContext -
Available on RenderContext, provided by the RenderContextTextExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shrink(
double factor) → RenderContext -
Available on RenderContext, provided by the RenderContextTextExt extension
-
textStyle(
) → TextStyle -
Available on RenderContext, provided by the RenderContextTextExt extension
-
toFractionChildStyle(
) → RenderContext -
Available on RenderContext, provided by the RenderContextTextExt extension
Style transformation when entering fraction children -
toLimitStyle(
) → RenderContext -
Available on RenderContext, provided by the RenderContextTextExt extension
Style transformation when entering large operator limits -
toScriptStyle(
) → RenderContext -
Available on RenderContext, provided by the RenderContextTextExt extension
Style transformation when entering subscripts/superscripts -
toString(
) → String -
A string representation of this object.
inherited
-
withColor(
String colorString) → RenderContext -
Available on RenderContext, provided by the RenderContextTextExt extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited