LayoutUtils class
Layout utility class, providing common measurement and alignment helper methods.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearCache(
) → void - Clears the cache (call this at the start of a new render cycle or when fonts change).
-
getAxisHeight(
RenderContext context) → double - Gets the Math Axis height of the current font. The Math Axis is the reference line for vertically centering fraction lines and operators (like +).