MathFontUtils class
Math Font Unicode Conversion Utility
When .ttf font files cannot be loaded directly, this maps Unicode math letter blocks to achieve \mathbb, \mathcal, \mathfrak effects.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
toBlackboardBold(
String text) → String - Converts to Blackboard Bold - \mathbb Mapping range: A-Z (U+1D538), a-z (U+1D552), 0-9 (U+1D7D8)
-
toCalligraphic(
String text) → String - Converts to Calligraphic - \mathcal Mapping range: A-Z (U+1D49C)